timerelationtools.TimeRelation
==============================

.. abjad-lineage:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation

.. autoclass:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.inequality
      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.is_fully_loaded
      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.is_fully_unloaded
      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.new
      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.storage_format
      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__call__
      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__eq__
      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__ne__
      ~abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.inequality
   :noindex:

.. autoattribute:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.is_fully_loaded
   :noindex:

.. autoattribute:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.is_fully_unloaded
   :noindex:

.. autoattribute:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.new
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__call__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__eq__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__ne__
   :noindex:

.. automethod:: abjad.tools.timerelationtools.TimeRelation.TimeRelation.TimeRelation.__repr__
   :noindex:
